# hdpl-conventions/prototype/hdpl/commune

This package contains features common to usage. In practice this means mostly
mathematical operations and/or ways to, based on an already working language,
work with others

Accusative	mathēmaticam

## Trivia
- "commūne"
  - Latin: https://en.wiktionary.org/wiki/communis#Latin
 - "mathēmaticam"
   - Latin: https://en.wiktionary.org/wiki/mathematica#Latin
